======
yasmll
======

.. image:: https://img.shields.io/travis/romulomontalvao/yasmll.svg
        :target: https://travis-ci.org/romulomontalvao/yasmll

.. image:: https://img.shields.io/pypi/v/yasmll.svg
        :target: https://pypi.python.org/pypi/yasmll


YASMLL: Yet Another Scientific Machine Learning Library

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://romulomontalvao.github.io/yasmll.

Features
--------

* TODO
